<?php
/**
 * Dragon Realms Designs' functions and definitions
 *
 * @package drdfunctions
 * @since drdfunctions 1.0
 */
/**
 * Custom Header Start.
 */
require get_template_directory() . '/inc/custom-head.php';
/**
 * Custom Header End.
 */

if ( ! function_exists( 'drdfunctions_support' ) ) :

	/**
	 * Sets up theme defaults and registers support for various WordPress features.
	 *
	 * @since DRD - Hive 1.5.8
	 *
	 * @return void
	 */
	function drdfunctions_support() {

		// Add support for block styles.
		add_theme_support( 'wp-block-styles' );
		add_theme_support( 'title-tag' );
		add_theme_support( 'responsive-embeds' );
		add_theme_support( 'custom-logo' );
		add_theme_support( 'custom-background' );
		add_theme_support( 'align-wide' );
		// Enqueue editor styles.
		add_editor_style( 'style.css' );
	}

endif;
add_action( 'after_setup_theme', 'drdfunctions_support' );

// Load Custom Stylesheets
function drdfunctions_load_css() {

	wp_register_style( 'bootstrap', get_template_directory_uri() . '/assets/css/bootstrap.min.css', array(), '5.3', 'all' );
	wp_enqueue_style( 'bootstrap' );

	wp_register_style( 'wordprescore', get_template_directory_uri() . '/assets/css/wordpress.css', array(), 'all', 'all' );
	wp_enqueue_style( 'wordpresscore' );

	wp_register_style( 'custom', get_template_directory_uri() . '/assets/css/custom.css', array(), 'all', 'all' );
	wp_enqueue_style( 'custom' );

}
add_action( 'wp_enqueue_scripts', 'drdfunctions_load_css' );

if ( ! function_exists( 'drdfunctions_styles' ) ) :

	/**
	 * Enqueue styles.
	 *
	 * @since DRD - Hive 1.5.8
	 *
	 * @return void
	 */
	function drdfunctions_styles() {
		// Register theme stylesheet.
		$theme_version = wp_get_theme()->get( 'Version' );

		$version_string = is_string( $theme_version ) ? $theme_version : false;
		wp_register_style(
			'drdfunctions-style',
			get_template_directory_uri() . '/style.css',
			array(),
			$version_string
		);

		// Enqueue theme stylesheet.
		wp_enqueue_style( 'drdfunctions-style' );

	}

endif;
add_action( 'wp_enqueue_scripts', 'drdfunctions_styles' );

// Load Javascript
function drdfunctions_load_js() {
	wp_enqueue_script( 'jquery' );
	wp_register_script( 'bootstrapjs', get_template_directory_uri() . '/assets/js/bootstrap.bundle.min.js', 'jquery', 'all', true );
	wp_enqueue_script( 'bootstrapjs' );

}
add_action( 'wp_enqueue_scripts', 'drdfunctions_load_js' );


if ( ! function_exists( 'drdfunctions_setup' ) ) :
	/**
	 * Sets up theme defaults and registers support for various WordPress features.
	 *
	 * Note that this function is hooked into the after_setup_theme hook, which runs
	 * before the init hook. The init hook is too late for some features, such as indicating
	 * support post thumbnails.
	 */
	function drdfunctions_setup() {
 
		/**
		 * Make theme available for translation.
		 * Translations can be placed in the /languages/ directory.
		 */
		load_theme_textdomain( 'drd-hive', get_template_directory() . '/languages' );
	
		/**
		 * Add default posts and comments RSS feed links to &lt;head>.
		 */
		add_theme_support( 'automatic-feed-links' );
	
		/**
		 * Enable support for post thumbnails and featured images.
		 */
		add_theme_support( 'post-thumbnails' );
	

	}
endif; // drdfunctions_setup
add_action( 'after_setup_theme', 'drdfunctions_setup' );

// This theme uses wp_nav_menu() in two locations.  
register_nav_menus(
	array( 
		'primary'   => __( 'Primary Navigation', 'drd-hive' ),
		'secondary' => __( 'Secondary Navigation', 'drd-hive' ),
	)
);

function drdfunctions_widgets_init() {
	register_sidebar(
		array(
			'name'          => __( 'Sidebar One', 'drd-hive' ),
			'id'            => 'sidebar-1',
			'description'   => __( 'Add widgets here to appear in sidebar', 'drd-hive' ),
			'before_widget' => '<div class="bottom-padding"><section id="%1$s" class="sidebar %2$s"><div class="scontent">',
			'after_widget'  => '</div></section></div>',
			'before_title'  => '<h2 class="widget-title">',
			'after_title'   => '</h2>',
		)
	);
 
	register_sidebar(
		array(
			'name'          => __( 'Sidebar Two', 'drd-hive' ),
			'id'            => 'sidebar-2',
			'description'   => __( 'Add widgets here to appear in sidebar', 'drd-hive' ),
			'before_widget' => '<div class="bottom-padding"><section id="%1$s" class="sidebar %2$s"><div class="scontent">',
			'after_widget'  => '</div></section></div>',
			'before_title'  => '<h2 class="widget-title">',
			'after_title'   => '</h2>',
		)
	);

}
add_action( 'widgets_init', 'drdfunctions_widgets_init' );

//makes replying look neat
if ( ! function_exists( 'drdfunctions_threaded_comments' ) ) :
	function drdfunctions_threaded_comments() {
		if ( get_option( 'thread_comments' ) ) {
			wp_enqueue_script( 'comment-reply' );
		}
	}
	add_action( 'wp_enqueue_scripts', 'drdfunctions_threaded_comments' );
endif;

// display information about a post under the post title
if ( ! function_exists( 'drdfunctions_post_meta' ) ) :
	function drdfunctions_post_meta() {
		echo '<div class="meta">';
		if ( get_post_type() === 'page' ) :
			printf(
				/* translators: %s = author */
				esc_html__( 'Posted by %s', 'drd-hive' ),
				get_the_author()
			);
		elseif ( has_category() ) :
			printf(
				/* translators: %1$s = date, %2$s = categories, %3$s = author */
				esc_html__( 'Posted on %1$s in %2$s by %3$s', 'drd-hive' ),
				get_the_date(),
				wp_kses_post( get_the_category_list( ',' ) ),
				get_the_author()
			);
		else :
			printf(
				/* translators: %1$s = date, %2$s = author */
				esc_html__( 'Posted on %1$s by %2$s', 'drd-hive' ),
				get_the_date(),
				get_the_author()
			);
		endif;
		edit_post_link( _x( 'Edit', 'verb', 'drd-hive' ), ' | ' );
		if ( get_post_type() !== 'page' && has_tag() ) :
			echo '<br>';
			the_tags();
		endif;
		echo '</div>';
	}
endif;

// displays "Comments are closed" instead of comment form when comments are closed.
if ( ! function_exists( 'drdfunctions_closed_comments' ) ) :
	function drdfunctions_closed_comments() {
		echo '<p>', esc_html__( 'Comments are closed.', 'drd-hive' ), '</p>';
	}
	add_action( 'comment_form_comments_closed', 'drdfunctions_closed_comments' );
endif;

// Add Header Widgets Section to customize
function drdfunctions_headerwidget( $wp_customize ) {
	$wp_customize->add_section(
		'drd-hive-headerwidget-section', 
		array(
			'title' => __( 'Custom Header Widgets', 'drd-hive' ),
		)
	);

	$wp_customize->add_control(
		new WP_Customize_Control(
			$wp_customize,
			'drd-hive-headerwidget-text-control', 
			array(
				'type'        => 'button',
				'settings'    => array(),
				'label'       => __( 'Get All the Features [5 Sidebars on each side (left and rights), (1)Header, (1)Footer]', 'drd-hive' ),
				'priority'    => 10,
				'section'     => 'drd-hive-headerwidget-section',
				'input_attrs' => array(
					'value'   => __( 'Get PRO Version', 'drd-hive' ),
					'class'   => 'button-secondary',
					'onclick' => "window.open('https://dragonrealmsdesigns.com/', '_blank')",
				),
			)
		)
	);
}

add_action( 'customize_register', 'drdfunctions_headerwidget' );

// Add Center Widgets Section to customize
function drdfunctions_centerwidgets( $wp_customize ) {
	$wp_customize->add_section(
		'drd-hive-centerwidgets-section', 
		array(
			'title' => __( 'Custom Center Widgets', 'drd-hive' ),
		)
	);

	$wp_customize->add_control(
		new WP_Customize_Control(
			$wp_customize,
			'drd-hive-centerwidgets-text-control',
			array(
				'type'        => 'button',
				'settings'    => array(),
				'label'       => __( 'Get All the Features [5 Sidebars on each side (left and rights), (1) Header, (1) Footer]', 'drd-hive' ),
				'priority'    => 10,
				'section'     => 'drd-hive-centerwidgets-section',
				'input_attrs' => array(
					'value'   => __( 'Get PRO Version', 'drd-hive' ),
					'class'   => 'button-secondary',
					'onclick' => "window.open('https://dragonrealmsdesigns.com/', '_blank')",
				),
			)
		)
	);
}

add_action( 'customize_register', 'drdfunctions_centerwidgets' );

// Add Footer Widgets Section to customize
function drdfunctions_fcontent( $wp_customize ) {
	$wp_customize->add_section(
		'drd-hive-fcontent-section', 
		array(
			'title' => __( 'Custom Footer Widgets', 'drd-hive' ),
		)
	);

	$wp_customize->add_control(
		new WP_Customize_Control(
			$wp_customize,
			'drd-hive-fcontent-text-control', 
			array(
				'type'        => 'button',
				'settings'    => array(),
				'label'       => __( 'Get All the Features [5 Sidebars on each side (left and rights), (1) Header, (1) Footer]', 'drd-hive' ),
				'priority'    => 10,
				'section'     => 'drd-hive-fcontent-section',
				'input_attrs' => array(
					'value'   => __( 'Get PRO Version', 'drd-hive' ),
					'class'   => 'button-secondary',
					'onclick' => "window.open('https://dragonrealmsdesigns.com/', '_blank')",
				),
			)
		)
	);
}

add_action( 'customize_register', 'drdfunctions_fcontent' );

// Add Sidebar Widgets Section to customize
function drdfunctions_leftrightwidgets( $wp_customize ) {
	$wp_customize->add_section(
		'drd-hive-leftrightwidgets-section', 
		array(
			'title' => __( 'Custom Sidebar Widgets', 'drd-hive' ),
		)
	);

	$wp_customize->add_control(
		new WP_Customize_Control(
			$wp_customize,
			'drd-hive-leftrightwidgets-text-control', 
			array(
				'type'        => 'button',
				'settings'    => array(),
				'label'       => __( 'Get All the Features [5 Sidebars on each side (left and rights), (1) Header, (1)Footer]', 'drd-hive' ),
				'priority'    => 10,
				'section'     => 'drd-hive-leftrightwidgets-section',
				'input_attrs' => array(
					'value'   => __( 'Get PRO Version', 'drd-hive' ),
					'class'   => 'button-secondary',
					'onclick' => "window.open('https://dragonrealmsdesigns.com/', '_blank')",
				),
			)
		)
	);
}

add_action( 'customize_register', 'drdfunctions_leftrightwidgets' );

//Custom Follow Me Social Bar
function drdfunctions_socialbar( $wp_customize ) {
	$wp_customize->add_section(
		'drdfunctions_socialbar_section',
		array(
			'title'       => esc_html__( 'Follow Me Social Bar', 'drd-hive' ),
			'description' => esc_html__( 'Add Social Bar Content', 'drd-hive' ),
			'priority'    => null,
		)
	);

	//Follow Me Social Icons
	$wp_customize->add_setting(
		'drdfunctions_facebook_url',
		array(
			'default'           => '',
			'sanitize_callback' => 'esc_url_raw',
		)
	);

	$wp_customize->add_control(
		'drdfunctions_facebook_url',
		array(
			'label'       => esc_html__( 'Facebook Link:', 'drd-hive' ),
			'description' => esc_html__( '--Erase the field and make blank to remove icons.', 'drd-hive' ),
			'section'     => 'drdfunctions_socialbar_section',
			'setting'     => 'drdfunctions_facebook_url',
			'type'        => 'url',
		)
	);

	$wp_customize->add_control(
		'labels',
		array(
			'type'        => 'button',
			'settings'    => array(),
			'label'       => __( 'Get more Social Links', 'drd-hive' ),
			'description' => esc_html__( 'Get more Social Links with PRO Version! [Googele+, Discord, Twitter, Linkedin, and more!', 'drd-hive' ),
			'priority'    => 10,
			'section'     => 'drdfunctions_socialbar_section',
			'input_attrs' => array(
				'value'   => __( 'GO PRO NOW!', 'drd-hive' ),
				'class'   => 'button-secondary',
				'onclick' => "window.open('https://www.dragonrealmsdesigns.com/', '_blank')",
			),
		)
	);

}
add_action( 'customize_register', 'drdfunctions_socialbar' );
	
	require_once get_template_directory() . '/inc/customize-pro/class-drdfunctions-customize-section-pro.php';
