<?php

function drdfunctions_custom_header_setup() {
	$args = array(
		// Text color and image (empty to use none).
		'default-text-color'     => 'ffffff',
		'default-image'          => '%s/assets/images/hdr/header.jpg',

		// Set height and width, with a maximum value for the width.
		'height'                 => 250,

		// Callbacks for styling the header and the admin preview.
		'wp-head-callback'       => 'drdfunctions_header_style',
		'admin-head-callback'    => 'drdfunctions_admin_header_style',
		'admin-preview-callback' => 'drdfunctions_admin_header_image',
	);
	add_theme_support( 'custom-header', $args );

	/*
	 * Default custom headers packaged with the theme.
	 * %s is a placeholder for the theme template directory URI.
	 */
	register_default_headers(
		array(
			'first'  => array(
				'url'           => '%s/assets/images/hdr/header.jpg',
				'thumbnail_url' => '%s/assets/images/hdr/thumbnail.jpg',
				'description'   => _x( 'First', 'header image description', 'drd-hive' ),
			),
			'second' => array(
				'url'           => '%s/assets/images/hdr/header.jpg',
				'thumbnail_url' => '%s/assets/images/hdr/thumbnail.jpg',
				'description'   => _x( 'Second', 'header image description', 'drd-hive' ),
			),
			'third'  => array(
				'url'           => '%s/assets/images/hdr/header.jpg',
				'thumbnail_url' => '%s/assets/images/hdr/thumbnail.jpg',
				'description'   => _x( 'Third', 'header image description', 'drd-hive' ),
			),
		)
	);
}
add_action( 'after_setup_theme', 'drdfunctions_custom_header_setup', 11 );


/**
 * Style the header text displayed on the blog.
 *
 * get_header_textcolor() options: Hide text (returns 'blank'), or any hex value.
 *
 * @since DRD Custom Header 1.0
 */
function drdfunctions_header_style() {
	$header_image = get_header_image();
	$text_color   = get_header_textcolor();

	// If no custom options for text are set, let's bail.
	if ( empty( $header_image ) && get_theme_support( 'custom-header', 'default-text-color' ) !== $text_color ) {
		return;
	}

	// If we get this far, we have custom styles.
	?>
	<style type="text/css" id="drdfunctions-header-css">
	<?php
	if ( ! empty( $header_image ) ) :
		?>
	.site-header {
		background: url(<?php header_image(); ?>) repeat-x;
		background-size: 2000px;
		height: 250px;
	}
	@media (max-width: 767px) {
		.site-header {
			background-size: 768px auto;
		}
	}
	@media (max-width: 359px) {
		.site-header {
			background-size: 360px auto;
		}
	}
		<?php
		endif;

		// Has the text been hidden?
	if ( ! display_header_text() ) :
		?>
	.site-title,
	.site-description {
		position: absolute;
		clip: rect(1px 1px 1px 1px); /* IE7 */
		clip: rect(1px, 1px, 1px, 1px);
	}
		<?php
		if ( empty( $header_image ) ) :
			?>
	.site-header .home-link {
	min-height: 0;
	}
			<?php
		endif;

		// If the user has set a custom color for the text, use that.
		elseif ( get_theme_support( 'custom-header', 'default-text-color' ) !== $text_color ) :
			?>
		.site-title,
		.site-description {
			color: #<?php echo esc_attr( $text_color ); ?>;
		}
	<?php endif; ?>
	</style>
	<?php
}

/**
 * Style the header image displayed on the Appearance > Header admin panel.
 *
 * @since DRD Custom Header 1.0
 */
function drdfunctions_admin_header_style() {
	$header_image = get_header_image();
	?>
	<style type="text/css" id="drdfunctions-admin-header-css">
	.appearance_page_custom-header #headimg {
		border: none;
		-webkit-box-sizing: border-box;
		-moz-box-sizing:    border-box;
		box-sizing:         border-box;
		<?php
		if ( ! empty( $header_image ) ) {
			echo 'background: url(' . esc_url( $header_image ) . ') no-repeat scroll top; background-size: 1600px auto;';
		}
		?>
		padding: 0 20px;
	}
	#headimg .home-link {
		-webkit-box-sizing: border-box;
		-moz-box-sizing:    border-box;
		box-sizing:         border-box;
		margin: 0 auto;
		max-width: 1040px;
		<?php
		if ( ! empty( $header_image ) || display_header_text() ) {
			echo 'min-height: 230px;';
		}
		?>
		width: 100%;
	}
	<?php if ( ! display_header_text() ) : ?>
	#headimg h1,
	#headimg h2 {
		position: absolute !important;
		clip: rect(1px 1px 1px 1px); /* IE7 */
		clip: rect(1px, 1px, 1px, 1px);
	}
	<?php endif; ?>
	#headimg h1 {
		font: bold 60px/1 Bitter, Georgia, serif;
		margin: 0;
		padding: 58px 0 10px;
	}
	#headimg h1 a {
		text-decoration: none;
	}
	#headimg h1 a:hover {
		text-decoration: underline;
	}
	#headimg h2 {
		font: 200 italic 24px "Source Sans Pro", Helvetica, sans-serif;
		margin: 0;
		text-shadow: none;
	}
	.default-header img {
		max-width: 230px;
		width: auto;
	}
	</style>
	<?php
}

/**
 * Output markup to be displayed on the Appearance > Header admin panel.
 *
 * This callback overrides the default markup displayed there.
 *
 * @since DRD Custom Header 1.0
 */
function drdfunctions_admin_header_image() {
	$style = 'color: #' . get_header_textcolor() . ';';
	if ( ! display_header_text() ) {
		$style = 'display: none;';
	}
	?>
	<div id="headimg" style="background: url(<?php echo esc_url( get_header_image() ); ?>) no-repeat scroll top; background-size: 1600px auto;">
		<div class="home-link">
			<h1 class="displaying-header-text"><a id="name" style="<?php echo esc_attr( $style ); ?>" onclick="return false;" href="#" tabindex="-1"><?php bloginfo( 'name' ); ?></a></h1>
			<h2 id="desc" class="displaying-header-text" style="<?php echo esc_attr( $style ); ?>"><?php bloginfo( 'description' ); ?></h2>
		</div>
	</div>
	<?php
}
